import React from "react";
import PropTypes from "prop-types";
import { useTranslation } from "react-i18next";
import Spinner from "../../../../components/common/Spinner";
import {
  BarChart,
  Bar,
  XAxis,
  YAxis,
  CartesianGrid,
  Tooltip,
  Legend,
  ResponsiveContainer
} from "recharts";

import SessionsRunningTimeChartTooltip from "./SessionsRunningTimeChartTooltip";

const SessionsRunningTimeChart = ({ data }) => {
  const { t } = useTranslation();

  const chartData = data.map((z) => {
    return {
      sessionId: z.sessionId,
      name: `S${z.orderNo}`,
      order: z.orderNo,
      value: z.runningTime.hours,
      label: z.runningTime.label
    };
  });

  const CustomTooltip = ({ active, payload }) => {
    if (!active) return null;
    return <SessionsRunningTimeChartTooltip payload={payload[0].payload} />;
  };

  CustomTooltip.propTypes = {
    active: PropTypes.bool.isRequired,
    payload: PropTypes.object
  };

  return (
    <>
      {data.loading || !data.loaded ? (
        <Spinner />
      ) : (
        <ResponsiveContainer width="100%" height={500}>
          <BarChart
            data={chartData}
            margin={{
              top: 5,
              right: 30,
              left: 20,
              bottom: 5
            }}
          >
            <CartesianGrid strokeDasharray="3 3" />
            <XAxis dataKey="name" />
            <YAxis type="number" dataKey="value" name="stature" unit="h" />
            <Tooltip content={<CustomTooltip />} />
            <Legend />

            <Bar dataKey="value" fill="#3f51b5" name="running time" />
          </BarChart>
        </ResponsiveContainer>
      )}
    </>
  );
};

SessionsRunningTimeChart.propTypes = {
  data: PropTypes.array.isRequired
};

export default SessionsRunningTimeChart;
